@@ -1,15 +1,12 @@
 package Padre::Plugin::Vi;
 use strict;
 use warnings;
-use 5.008005;
 
 use base 'Padre::Plugin';
 
 use Scalar::Util qw(refaddr);
-use Padre::Util ('_T');
-use Padre::Constant ();
 
-our $VERSION = '0.23';
+our $VERSION = '0.21';
 
 =head1 NAME
 
@@ -25,7 +22,7 @@ The 3 basic modes of vi are in development:
 When you turn on vi-mode, or load Padre with vi-mode already enabled
 you reach the normal navigation mode of vi.
 
-We don't plan to implement many of the configuration options of vi. 
+We don't plan to impelement many of the configuration options of vi. 
 Even parts that are going to be implemented will not use the same method
 of configuration.
 
@@ -137,7 +134,7 @@ Nyw - yank N words
 
 =item *
 
-u - undo last editing
+u - undu last editing
 
 =item *
 
@@ -155,7 +152,7 @@ G - jump to last line
 
 =item *
 
-w, Nw - next word, forward N words
+w, Nw - next word, forwad N words
 
 =item *
 
@@ -221,7 +218,7 @@ separate mapping of numbers to buffers and files.
 
 =head1 TODO
 
-Better indication that Padre is in vi-mode.
+Better indication that Padre is  in vi-mode.
 
 Change the cursor for navigation mode and back to insert mode.
 (fix i)
@@ -248,7 +245,7 @@ r for replacing current character
 =cut
 
 sub padre_interfaces {
-	'Padre::Plugin' => 0.43;
+	'Padre::Plugin' => 0.18,
 }
 
 sub plugin_enable {
@@ -256,16 +253,15 @@ sub plugin_enable {
 
 	require Padre::Plugin::Vi::Editor;
 	require Padre::Plugin::Vi::CommandLine;
-
-	#	foreach my $editor ( Padre->ide->wx->main->pages ) {
-	#		$self->editor_enable($editor);
-	#	}
+#	foreach my $editor ( Padre->ide->wx->main_window->pages ) {
+#		$self->editor_enable($editor);
+#	}
 }
 
 sub plugin_disable {
 	my ($self) = @_;
 
-	foreach my $editor ( Padre->ide->wx->main->pages ) {
+	foreach my $editor ( Padre->ide->wx->main_window->pages ) {
 		$self->editor_stop($editor);
 	}
 	delete $INC{"Padre/Plugin/Vi/Editor.pm"};
@@ -274,28 +270,28 @@ sub plugin_disable {
 }
 
 sub editor_enable {
-	my ( $self, $editor, $doc ) = @_;
-
-	$self->{editor}{ refaddr $editor} = Padre::Plugin::Vi::Editor->new($editor);
+	my ($self, $editor, $doc) = @_;
+	
+	$self->{editor}{refaddr $editor} = Padre::Plugin::Vi::Editor->new($editor);
 
 	Wx::Event::EVT_KEY_DOWN( $editor, sub { $self->evt_key_down(@_) } );
-	Wx::Event::EVT_CHAR( $editor, sub { $self->evt_char(@_) } );
+	Wx::Event::EVT_CHAR(     $editor, sub { $self->evt_char(@_) } );
 
 	return 1;
 }
 
 sub editor_stop {
-	my ( $self, $editor, $doc ) = @_;
-
-	delete $self->{editor}{ refaddr $editor};
+	my ($self, $editor, $doc) = @_;
+	
+	delete $self->{editor}{refaddr $editor};
 	Wx::Event::EVT_KEY_DOWN( $editor, undef );
-	Wx::Event::EVT_CHAR( $editor, undef );
+	Wx::Event::EVT_CHAR(     $editor, undef );
 
 	return 1;
 }
 
 sub menu_plugins_simple {
-	return ( "Vi mode" => [ _T('About') => \&about ] );
+	return ("Vi mode" => ['About' => \&about ]);
 }
 
 sub about {
@@ -303,47 +299,49 @@ sub about {
 
 	my $about = Wx::AboutDialogInfo->new;
 	$about->SetName("Padre::Plugin::Vi");
-	$about->SetDescription("Try to emulate the vi modes of operation\n");
+	$about->SetDescription(
+		"Try to emulate the vi modes of operation\n"
+	);
 	$about->SetVersion($Padre::Plugin::Vi::VERSION);
-	$about->SetCopyright( _T("Copyright 2008 Gabor Szabo") );
+	$about->SetCopyright(Wx::gettext("Copyright 2008 Gabor Szabo"));
 
 	# Only Unix/GTK native about box supports websites
-	if (Padre::Constant::WXGTK) {
+	if ( Padre::Util::WXGTK ) {
 		$about->SetWebSite("http://padre.perlide.org/");
 	}
 
 	$about->AddDeveloper("Gabor Szabo");
 
-	Wx::AboutBox($about);
+	Wx::AboutBox( $about );
 	return;
 }
 
 sub evt_key_down {
-	my ( $self, $editor, $event ) = @_;
+	my ($self, $editor, $event) = @_;
 
-	my $mod = $event->GetModifiers || 0;
+	my $mod  = $event->GetModifiers || 0;
 	my $code = $event->GetKeyCode;
 
 	#print("key: '$mod', '$code'\n");
-	if ( 32 <= $code and $code <= 127 ) {
+	if (32 <= $code and $code <= 127) {
 		$event->Skip;
 		return;
 	}
 
-	my $skip = $self->{editor}{ refaddr $editor}->key_down( $mod, $code );
+	my $skip = $self->{editor}{refaddr $editor}->key_down($mod, $code);
 	$event->Skip($skip);
 	return;
 }
 
 sub evt_char {
-	my ( $self, $editor, $event ) = @_;
+	my ($self, $editor, $event) = @_;
 
-	my $mod = $event->GetModifiers || 0;
+	my $mod  = $event->GetModifiers || 0;
 	my $code = $event->GetKeyCode;
 
 	#printf("char: '$mod', '$code' '%s'\n", chr($code));
-	if ( 32 <= $code and $code <= 127 ) {
-		my $skip = $self->{editor}{ refaddr $editor}->get_char( $mod, $code, chr($code) );
+	if (32 <= $code and $code <= 127) {
+		my $skip = $self->{editor}{refaddr $editor}->get_char($mod, $code, chr($code));
 		$event->Skip($skip);
 	}
 	return;
@@ -351,7 +349,7 @@ sub evt_char {
 
 1;
 
-# Copyright 2008-2010 Gabor Szabo.
+# Copyright 2008 Gabor Szabo.
 # LICENSE
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl 5 itself.
